#   Meerkat: a product to add meerkat news to a site
#   Copyright (C) 2001  Carlos de la Guardia
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    

import sys
import string
import time

import Globals
from Globals import Persistent, Acquisition
import AccessControl
import OFS

import ZODB, ZODB.FileStorage

import xmlrpclib

class Meerkat(
    Acquisition.Implicit,
    Persistent,
    AccessControl.Role.RoleManager,
    OFS.SimpleItem.Item,
    ):
    "Meerkat product"

    __ac_permissions__=(
        ('View management screens',('manage_main',)),
        ('View', ('index_html')),
        ('Change settings',('manage_edit',),('Manager',)),
        )

    manage_options=(
        {'label':'Properties','action':'manage_main'},
        {'label':'View','action':''},
        )+OFS.SimpleItem.SimpleItem.manage_options

    meta_type='Meerkat'

    index_html=Globals.HTMLFile("Meerkat", globals())
    manage_main=Globals.HTMLFile("edit_Meerkat",globals())

    def __init__(self, id, server):
        self.id=id
        self.server=server
	self.category=0
	self.num_items=5

    def manage_edit(self, server, category, num_items, REQUEST=None):
        "Edit the settings."
        self.server=server
	self.category=category
	self.num_items=num_items
        if REQUEST is not None:
            return Globals.MessageDialog(title='Edited',message='<strong>%s</strong> has been edited.' % self.id, action='manage_main',)

    def getNews(self):
	"Get configured news items"
	server=xmlrpclib.Server(self.server)
	query={}
	if self.category!='0':
	    query['category']=self.category
	query['num_items']=self.num_items
	items=server.meerkat.getItems(query)
	return tuple(items)
	
    def getRelatedNews(self, searchword):
	"Get related news items"
	server=xmlrpclib.Server(self.server)
	query={}
	query['search']=searchword
	query['num_items']=self.num_items
	items=server.meerkat.getItems(query)
	return tuple(items)
	
    def getNewsHTML(self,style):
	"Get configured news items in HTML format"
	server=xmlrpclib.Server(self.server)
	query={}
	if self.category!='0':
	    query['category']=self.category
	query['num_items']=self.num_items
	items=server.meerkat.getItems(query)
	html='<ul>'
	for item in items:
	    html=html+'<li><a href=\"'+item['link']+'\"> '+item['title']+'</a>'
	    if style=='1':
		html=html+'<br>'+item['description']
	html=html+'</ul>'
	return html
	
    def getRelatedNewsHTML(self,searchword,style):
	"Get related news items in HTML format"
	server=xmlrpclib.Server(self.server)
	query={}
	query['search']=searchword
	query['num_items']=self.num_items
	items=server.meerkat.getItems(query)
	html='<ul>'
	for item in items:
	    html=html+'<li><a href=\"'+item['link']+'\"> '+item['title']+'</a>'
	    if style=='1':
		html=html+'<br>'+item['description']
	html=html+'</ul>'
	return html
	
    def getCategories(self):
	"Get all Meerkat categories"
	server=xmlrpclib.Server(self.server)
	categories=server.meerkat.getCategories()
	return tuple(categories)

    def getChannels(self):
	"Get all Meerkat channels"
	server=xmlrpclib.Server(self.server)
	channels=server.meerkat.getChannels()
	return tuple(channels)

    def getChannelsByCategory(self, category):
	"Get all Meerkat channels for a given category"
	server=xmlrpclib.Server(self.server)
	channels=server.meerkat.getChannelsByCategory(category)
	return tuple(channels)

    def getItems(self, channel=0, category=0, item='', search='', time_period='', profile=0, mob=0, url='', ids=0, descriptions=0, categories=0, channels=0, dates=0, num_items=''):
	"Get items using all parameters"
	server=xmlrpclib.Server(self.server)
	query={}
	if channel:
	    query['channel']=channel
	if category:
	    print 'in category, damn'
	    query['category']=category
	if item:
	    query['item']=item
	if search:
	    query['search']=search
	if time_period:
	    query['time_period']=time_period
	if profile:
	    query['profile']=profile
	if mob:
	    query['mob']=mob
	if url:
	    query['url']=url
	if ids:
	    query['ids']=ids
	if descriptions:
	    query['descriptions']=descriptions
	if categories:
	    query['categories']=categories
	if channels:
	    query['channels']=channels
	if dates:
	    query['dates']=dates
	if num_items:
	    query['num_items']=num_items
	items=server.meerkat.getItems(query)
	return tuple(items)

Globals.default__class_init__(Meerkat)

def manage_addMeerkat(self, id, server, REQUEST=None):
    "Create a Meerkat"
    meerkat=Meerkat(id, server)
    self._setObject(id, meerkat)
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

manage_addMeerkatForm=Globals.HTMLFile('add_Meerkat', globals())
